==> HostCMS-6.1.7.tar: modules/shop/delivery/condition/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2013 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Delivery conditions',
	'show_cond_of_delivery_title' => "List of delivery conditions of delivery type \"%s\"",
	'show_cond_of_delivery' => "Delivery conditions",
	'show_cond_of_delivery_add' => "Add",
	'show_cond_of_delivery_import' => "Import",
	'cond_of_delivery_edit_form_title' => "Edit delivery conditions",
	'cond_of_delivery_add_form_title' => "Add delivery conditions",
	'name' => "<acronym title=\"Name of delivery condition\">Name</acronym>",
	'active' => "<acronym title=\"Activity of delivery condition\">Active</acronym>",
	'delivery_time' => "<acronym title=\"Delivery time\">Delivery time</acronym>",
	'shop_country_id' => "<acronym title=\"Country of delivery\">Country</acronym>",
	'shop_country_location_id' => "<acronym title=\"Location of delivery\">Location</acronym>",
	'shop_country_location_city_id' => "<acronym title=\"Delivery city/town\">City/town</acronym>",
	'shop_country_location_city_area_id' => "<acronym title=\"Region of delivery\">Region</acronym>",
	'min_weight' => "Order weight from (%s); if 0 &mdash; minimum order weight is unlimited",
	'max_weight' => "Order weight to (%s); if 0 &mdash; maximum order weight is unlimited",
	'min_price' => "Order price from; if 0 &mdash; minimum order price is unlimited",
	'max_price' => "Order price to; if 0 &mdash; maximum order price is unlimited",
	'description' => "<acronym title=\"Description of delivery condition\">Description</acronym>",
	'price' => "<acronym title=\"Amount of ordered products\">Order amount</acronym>",
	'shop_tax_id' => "Tax value",
	'cond_of_delivery_tab' => "Delivery conditions",
	'shop_delivery_id' => "<acronym title=\"Delivery type that delivery condition belongs to\">Delivery type that delivery condition belongs to</acronym>",
	'id' => 'Id',
	'edit_success' => "Delivery condition information added successfully!",
	'shop_measure_not_checked' => "The measure is not selected for shop",
	'markDeleted_success' => "Delivery conditions deleted successfully!",
	'import_button' => "Import",
	'import_price_list_file_type' => "<acronym title=\"Type of file to be uploaded\">Select file type</acronym>",
	'msg_import_file' => 'Import file not specified!',
	'import_delivery_result' => "There were %s elements imported",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'changeStatus_success' => "Information has been successfully changed",	
	'marking' => "<acronym title=\"Marking of goods\">Marking of goods</acronym>",
	'sorting' => "<acronym title=\"Sorting order\">Sorting order</acronym>",
	'apply_success' => "Information has been successfully changed",
	'shop_country_id_inverted' => "Not",
	'shop_country_location_id_inverted' => "Not",
	'shop_country_location_city_id_inverted' => "Not",
	'shop_country_location_city_area_id_inverted' => "Not",
);

==> HostCMS-6.8.6.tar: modules/shop/delivery/condition/i18n/en.php <==
<?php
/**
 * Online shop.
 *
 * @package HostCMS
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'model_name' => 'Delivery conditions',
	'show_cond_of_delivery_title' => "Conditions for delivery \"%s\"",
	'show_cond_of_delivery' => "Delivery conditions",
	'show_cond_of_delivery_add' => "Add",
	'show_cond_of_delivery_import' => "Import",
	'cond_of_delivery_edit_form_title' => "Edit delivery conditions",
	'cond_of_delivery_add_form_title' => "Add delivery conditions",
	'name' => "Name",
	'active' => "Active",
	'delivery_time' => "Delivery time",
	'shop_country_id' => "Country",
	'shop_country_location_id' => "Location",
	'shop_country_location_city_id' => "City/town",
	'shop_country_location_city_area_id' => "Region",
	'min_weight' => "Order weight from (%s); if 0 &mdash; minimum order weight is unlimited",
	'max_weight' => "Order weight to (%s); if 0 &mdash; maximum order weight is unlimited",
	'min_price' => "Order price from; if 0 &mdash; minimum order price is unlimited",
	'max_price' => "Order price to; if 0 &mdash; maximum order price is unlimited",
	'description' => "Description",
	'price' => "Order amount",
	'shop_tax_id' => "Tax value",
	'cond_of_delivery_tab' => "Delivery conditions",
	'shop_delivery_id' => "Delivery condition belongs to",
	'id' => 'ID',
	'edit_success' => "Delivery condition information added successfully!",
	'shop_measure_not_checked' => "The measure is not selected for shop",
	'markDeleted_success' => "Delivery conditions deleted successfully!",
	'import_button' => "Import",
	'import_price_list_file_type' => "Select file",
	'msg_import_file' => 'Import file not specified!',
	'import_delivery_result' => "There were %s elements imported",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
	'changeStatus_success' => "Information has been successfully changed",
	'marking' => "Delivery Marking",
	'sorting' => 'Sort',
	'apply_success' => "Information has been successfully changed",
	'inverted' => "Not",
);
